@@ -1,4 +1,4 @@
 let foo;
 {
-    let foo1;
+    let foo__2;
 }
