@@ -1,6 +1,9 @@
 class x87 {
     constructor(parm__2: () => Base[] = function named__3() {
-        return [d1, d2];
+        return [
+            d1,
+            d2
+        ];
     }){
     }
 }
@@ -8,7 +11,10 @@ class x90 {
     constructor(parm__4: {
         () : Base[];
     } = function named__5() {
-        return [d1, d2];
+        return [
+            d1,
+            d2
+        ];
     }){
     }
 }
